@@ -191,9 +191,6 @@ def MessageEmitterMethod(
             **kwargs
         ):
             verb = HttpDomain.Verb.POST
-            # print(f'logRequest: {logRequest}')
-            # print(f'resourceMethodConfig.wrapperManager.resourceInstance.logRequest: {resourceMethodConfig.wrapperManager.resourceInstance.logRequest}, resourceMethodConfig.wrapperManager.logRequest: {resourceMethodConfig.wrapperManager.logRequest}')
-            # print(f'resourceMethodConfig.wrapperManager.shouldLogRequest(): {resourceMethodConfig.wrapperManager.shouldLogRequest()}')
             url, params, headers, body, timeout, logRequest = ClientUtil.parseParameters(
                 resourceInstance,
                 resourceMethodConfig,
@@ -209,7 +206,7 @@ def MessageEmitterMethod(
                     )
                 ),
                 timeout,
-                logRequest and resourceMethodConfig.wrapperManager.shouldLogRequest()
+                resourceMethodConfig.wrapperManager.shouldLogRequest()
             )
             doLogRequest(verb, url, body, params, headers, logRequest, kwargs)
             emitterMethodResponse = requests.post(
@@ -245,6 +242,7 @@ def MessageEmitterMethod(
         def innerResourceInstanceMethod(*args, **kwargs):
             f'''(*args, {FlaskUtil.KW_HEADERS}={{}}, {FlaskUtil.KW_PARAMETERS}={{}}, **kwargs)'''
             wrapperManager.updateResourceInstance(args)
+            resourceMethodConfig.logRequest = wrapperManager.shouldLogRequest()
             httpClientResolversMap = HTTP_CLIENT_RESOLVERS_MAP
             resourceMethodGroupKey = None if MessageConstant.GROUP_KEY_CLIENT_ATTRIBUTE_NAME not in kwargs else kwargs.pop(MessageConstant.GROUP_KEY_CLIENT_ATTRIBUTE_NAME)
             resourceMethodMessageKey = None if MessageConstant.MESSAGE_KEY_CLIENT_ATTRIBUTE_NAME not in kwargs else kwargs.pop(MessageConstant.MESSAGE_KEY_CLIENT_ATTRIBUTE_NAME)
